Exception: Ace::Git::AmbiguousRemoteError

Inherits:
Error
  • Object
show all
Defined in:
lib/ace/git/errors.rb

Overview

A remote URL matches multiple configured servers, or none, so the server identity cannot be determined without caller input.